"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const CSSVariableManager_1 = __importDefault(require("../../CSSVariableManager"));
const path = __importStar(require("path"));
async function runTest(fixturePath, additionalChecks) {
    const cssManager = new CSSVariableManager_1.default();
    await cssManager.parseAndSyncVariables([path.join(__dirname, fixturePath)]);
    const allVars = cssManager.getAll();
    expect(allVars.get('--main-bg-color').symbol.value).toEqual('brown');
    expect(allVars.get('--h1').symbol.value).toEqual('26px');
    expect(allVars.get('--h2').symbol.value).toEqual('22px');
    expect(allVars.get('--h3').symbol.value).toEqual('18px');
    expect(allVars.get('--text-base').symbol.value).toEqual('16px');
    expect(allVars.get('--carousel-bg').symbol.value).toEqual('var(--main-bg-color)');
    expect(allVars.get('--child-main-bg-color').symbol.value).toEqual('brown');
    expect(allVars.get('--child-h1').symbol.value).toEqual('26px');
    expect(allVars.get('--child-h2').symbol.value).toEqual('22px');
    expect(allVars.get('--child-h3').symbol.value).toEqual('18px');
    // expect(allVars.get('--child-text-base').symbol.value).toEqual('16px');
    expect(allVars.get('--child-carousel-bg').symbol.value).toEqual('var(--main-bg-color)');
    if (typeof additionalChecks === 'function') {
        await additionalChecks(allVars);
    }
}
describe('CSS Variable Manager', () => {
    test('can parse variables from css files', async () => {
        await runTest('../fixtures/css-nested');
    });
    test('can parse variables from less files', async () => {
        await runTest('../fixtures/less-nested');
    });
    test('can parse variables from scss files', async () => {
        await runTest('../fixtures/scss-nested');
    });
    test('can parse variables from mixed files', async () => {
        await runTest('../fixtures/mixed-nested');
    });
    test('can parse variables from tailwind @layer', async () => {
        await runTest('../fixtures/tailwindcss-nested');
    });
    test('can parse variables from remote url', async () => {
        await runTest('../fixtures/import-url', (allVars) => {
            expect(allVars.get('--slate-50').symbol.value).toEqual('#f8fafc');
        });
    });
});
//# sourceMappingURL=CSSVariableManager.test.js.map